@@ -5,4 +5,4 @@ Provider for basic email messages
 """
 from .email import Email
 
-__all__ = ['Email']
+__all__ = ('Email', )
